{% extends "base.html" %}

{% block content %}
<div class="archive-day">
    <h1>{{ day|date:"F d, Y" }}</h1>

    <div class="archive-list">
        <ul>
            {% for object in object_list %}
                <li>
                    <a href="{{ object.get_absolute_url }}">{{ object }}</a>
                </li>
            {% empty %}
                <li>No data for this day.</li>
            {% endfor %}
        </ul>
    </div>

    <div class="archive-nav">
        <a href="{% url 'cs_archive:month' year=day|date:'Y' month=day|date:'m' %}">Monthly view</a>
    </div>
</div>
{% endblock %}